@@ -1,7 +1,8 @@
-__version__ = '0.3.0'
+__version__ = '0.8.4'
 
 from .pydtc import (
     connect,
+    connect_dbapi,
     load_temp,
     create_temp,
     read_sql,
@@ -17,7 +18,9 @@ from .pydtc import (
 from .utils import (
     exec_time,
     retry,
-    async_retry
+    async_retry,
+    DTCTimeoutException,
+    timeout
 )
 
 from .formauth import HttpFormAuth
\ No newline at end of file
